==> gpgmepp-15.08.3-1-aarch64.pkg.tar.xz: usr/lib/cmake/KF5Gpgmepp/KF5GpgmeppTargets-release.cmake <==
#----------------------------------------------------------------
# Generated CMake target import file for configuration "Release".
#----------------------------------------------------------------

# Commands may need to know the format version.
set(CMAKE_IMPORT_FILE_VERSION 1)

# Import target "KF5::Gpgmepp" for configuration "Release"
set_property(TARGET KF5::Gpgmepp APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(KF5::Gpgmepp PROPERTIES
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/libKF5Gpgmepp.so.4.79.0"
  IMPORTED_SONAME_RELEASE "libKF5Gpgmepp.so.5"
  )

list(APPEND _IMPORT_CHECK_TARGETS KF5::Gpgmepp )
list(APPEND _IMPORT_CHECK_FILES_FOR_KF5::Gpgmepp "${_IMPORT_PREFIX}/lib/libKF5Gpgmepp.so.4.79.0" )

# Import target "KF5::Gpgmepp-pthread" for configuration "Release"
set_property(TARGET KF5::Gpgmepp-pthread APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(KF5::Gpgmepp-pthread PROPERTIES
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/libKF5Gpgmepp-pthread.so.4.79.0"
  IMPORTED_SONAME_RELEASE "libKF5Gpgmepp-pthread.so.5"
  )

list(APPEND _IMPORT_CHECK_TARGETS KF5::Gpgmepp-pthread )
list(APPEND _IMPORT_CHECK_FILES_FOR_KF5::Gpgmepp-pthread "${_IMPORT_PREFIX}/lib/libKF5Gpgmepp-pthread.so.4.79.0" )

# Import target "KF5::QGpgme" for configuration "Release"
set_property(TARGET KF5::QGpgme APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(KF5::QGpgme PROPERTIES
  IMPORTED_LINK_DEPENDENT_LIBRARIES_RELEASE "KF5::Gpgmepp;KF5::Gpgmepp-pthread"
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/libKF5QGpgme.so.4.79.0"
  IMPORTED_SONAME_RELEASE "libKF5QGpgme.so.5"
  )

list(APPEND _IMPORT_CHECK_TARGETS KF5::QGpgme )
list(APPEND _IMPORT_CHECK_FILES_FOR_KF5::QGpgme "${_IMPORT_PREFIX}/lib/libKF5QGpgme.so.4.79.0" )

# Commands beyond this point should not need to know the version.
set(CMAKE_IMPORT_FILE_VERSION)

==> gpgmepp-15.12.3-1-aarch64.pkg.tar.xz: usr/lib/cmake/KF5Gpgmepp/KF5GpgmeppTargets-release.cmake <==
#----------------------------------------------------------------
# Generated CMake target import file for configuration "Release".
#----------------------------------------------------------------

# Commands may need to know the format version.
set(CMAKE_IMPORT_FILE_VERSION 1)

# Import target "KF5::Gpgmepp" for configuration "Release"
set_property(TARGET KF5::Gpgmepp APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(KF5::Gpgmepp PROPERTIES
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/libKF5Gpgmepp.so.4.80.0"
  IMPORTED_SONAME_RELEASE "libKF5Gpgmepp.so.5"
  )

list(APPEND _IMPORT_CHECK_TARGETS KF5::Gpgmepp )
list(APPEND _IMPORT_CHECK_FILES_FOR_KF5::Gpgmepp "${_IMPORT_PREFIX}/lib/libKF5Gpgmepp.so.4.80.0" )

# Import target "KF5::Gpgmepp-pthread" for configuration "Release"
set_property(TARGET KF5::Gpgmepp-pthread APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(KF5::Gpgmepp-pthread PROPERTIES
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/libKF5Gpgmepp-pthread.so.4.80.0"
  IMPORTED_SONAME_RELEASE "libKF5Gpgmepp-pthread.so.5"
  )

list(APPEND _IMPORT_CHECK_TARGETS KF5::Gpgmepp-pthread )
list(APPEND _IMPORT_CHECK_FILES_FOR_KF5::Gpgmepp-pthread "${_IMPORT_PREFIX}/lib/libKF5Gpgmepp-pthread.so.4.80.0" )

# Import target "KF5::QGpgme" for configuration "Release"
set_property(TARGET KF5::QGpgme APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(KF5::QGpgme PROPERTIES
  IMPORTED_LINK_DEPENDENT_LIBRARIES_RELEASE "KF5::Gpgmepp-pthread"
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/libKF5QGpgme.so.4.80.0"
  IMPORTED_SONAME_RELEASE "libKF5QGpgme.so.5"
  )

list(APPEND _IMPORT_CHECK_TARGETS KF5::QGpgme )
list(APPEND _IMPORT_CHECK_FILES_FOR_KF5::QGpgme "${_IMPORT_PREFIX}/lib/libKF5QGpgme.so.4.80.0" )

# Commands beyond this point should not need to know the version.
set(CMAKE_IMPORT_FILE_VERSION)
